@@ -26,7 +26,7 @@ import xmlrpc.client
 import yaml
 
 from .__about__ import __version__
-from .utils import parse_version, VERSION_LATEST
+from .utils import loader, parse_version, VERSION_LATEST, exc2str
 
 from .commands import (
     aliases,
@@ -104,7 +104,9 @@ def load_config(identity):
 
     try:
         with open(config_filename, "r", encoding="utf-8") as f_conf:
-            config = yaml.safe_load(f_conf.read())
+            config = yaml.load(  # nosec - loader() returns a safe loader
+                f_conf.read(), Loader=loader()
+            )
         return config[identity]
     except (FileNotFoundError, KeyError, TypeError):
         return {}
@@ -227,7 +229,7 @@ def main():
             proxy = xmlrpc.client.ServerProxy(uri, allow_none=True, transport=transport)
             version = proxy.system.version()
         except (OSError, xmlrpc.client.Error) as exc:
-            print(exc)
+            print("Unable to connect: %s" % exc2str(exc))
             return 1
 
         # Parse version
@@ -252,14 +254,15 @@ def main():
         print(exc)
         return 1
     except xmlrpc.client.Error as exc:
+        msg = exc.errmsg if hasattr(exc, "errmsg") else str(exc)
         if "sub_sub_command" in options:
             print(
                 "Unable to call '%s.%s': %s"
-                % (options.sub_command, options.sub_sub_command, str(exc))
+                % (options.sub_command, options.sub_sub_command, msg)
             )
         else:
-            print("Unable to call '%s': %s" % (options.sub_command, str(exc)))
+            print("Unable to call '%s': %s" % (options.sub_command, msg))
     except BaseException as exc:
-        print("Unknown error when connecting to '%s': %s" % (options.uri, str(exc)))
+        print("Unknown error: %s" % str(exc))
 
     return 1
