@@ -31,9 +31,9 @@ def configure_parser(parser, version):
 
     # "add"
     devices_add = sub.add_parser("add", help="add a device")
-    devices_add.add_argument("hostname", help="hostname of the device")
+    devices_add.add_argument("name", help="name of the device")
     devices_add.add_argument("--type", required=True, help="device-type")
-    devices_add.add_argument("--worker", required=True, help="worker hostname")
+    devices_add.add_argument("--worker", required=True, help="worker name")
     devices_add.add_argument("--description", default=None, help="device description")
 
     owner = devices_add.add_mutually_exclusive_group()
@@ -75,7 +75,7 @@ def configure_parser(parser, version):
     )
     dict_sub.required = True
     dict_get = dict_sub.add_parser("get", help="get the device dictionary")
-    dict_get.add_argument("hostname", help="hostname of the device")
+    dict_get.add_argument("name", help="name of the device")
     dict_get.add_argument(
         "field", nargs="?", default=None, help="only show the given sub-fields"
     )
@@ -90,7 +90,7 @@ def configure_parser(parser, version):
     )
 
     dict_set = dict_sub.add_parser("set", help="set the device dictionary")
-    dict_set.add_argument("hostname", help="hostname of the device")
+    dict_set.add_argument("name", help="name of the device")
     dict_set.add_argument(
         "config", type=argparse.FileType("r"), help="device dictionary file"
     )
@@ -127,7 +127,7 @@ def configure_parser(parser, version):
         devices_maintenance = sub.add_parser(
             "maintenance", help="maintenance the device"
         )
-        devices_maintenance.add_argument("hostname", help="device hostname")
+        devices_maintenance.add_argument("name", help="device name")
         devices_maintenance.add_argument(
             "--force",
             default=False,
@@ -144,7 +144,7 @@ def configure_parser(parser, version):
 
     # "show"
     devices_show = sub.add_parser("show", help="show device details")
-    devices_show.add_argument("hostname", help="device hostname")
+    devices_show.add_argument("name", help="device name")
     out_format = devices_show.add_mutually_exclusive_group()
     out_format.add_argument(
         "--json",
@@ -170,15 +170,15 @@ def configure_parser(parser, version):
     )
     tags_sub.required = True
     tags_add = tags_sub.add_parser("add", help="add a tag")
-    tags_add.add_argument("hostname", help="hostname of the device")
+    tags_add.add_argument("name", help="name of the device")
     tags_add.add_argument("tag", help="name of the tag")
 
     tags_del = tags_sub.add_parser("delete", help="remove a tag")
-    tags_del.add_argument("hostname", help="hostname of the device")
+    tags_del.add_argument("name", help="name of the device")
     tags_del.add_argument("tag", help="name of the tag")
 
     tags_list = tags_sub.add_parser("list", help="list tags for the device")
-    tags_list.add_argument("hostname", help="hostname of the device")
+    tags_list.add_argument("name", help="name of the device")
     out_format = tags_list.add_mutually_exclusive_group()
     out_format.add_argument(
         "--json",
@@ -198,8 +198,8 @@ def configure_parser(parser, version):
 
     # "update"
     devices_update = sub.add_parser("update", help="update device properties")
-    devices_update.add_argument("hostname", help="hostname of the device")
-    devices_update.add_argument("--worker", default=None, help="worker hostname")
+    devices_update.add_argument("name", help="name of the device")
+    devices_update.add_argument("--worker", default=None, help="worker name")
     devices_update.add_argument(
         "--description", default=None, help="device description"
     )
@@ -245,7 +245,7 @@ def help_string():
 def handle_add(proxy, options, config):
     if config["version"] >= (2018, 1):
         proxy.scheduler.devices.add(
-            options.hostname,
+            options.name,
             options.type,
             options.worker,
             options.user,
@@ -256,7 +256,7 @@ def handle_add(proxy, options, config):
         )
     else:
         proxy.scheduler.devices.add(
-            options.hostname,
+            options.name,
             options.type,
             options.worker,
             options.user,
@@ -292,7 +292,7 @@ def _lookups(value, fields):
 def handle_dict(proxy, options, _):
     if options.sub_sub_sub_command == "get":
         config = proxy.scheduler.devices.get_dictionary(
-            options.hostname, options.render, options.context
+            options.name, options.render, options.context
         )
         if not options.field:
             print(str(config).rstrip("\n"))
@@ -325,7 +325,7 @@ def handle_dict(proxy, options, _):
 
     else:
         config = options.config.read()
-        ret = proxy.scheduler.devices.set_dictionary(options.hostname, config)
+        ret = proxy.scheduler.devices.set_dictionary(options.name, config)
         if not ret:
             print("Unable to set the configuration")
         return 0 if ret else 1
@@ -361,9 +361,9 @@ def handle_list(proxy, options, config):
 
 def handle_maintenance(proxy, options, _):
     proxy.scheduler.devices.update(
-        options.hostname, None, None, None, None, "MAINTENANCE", None
+        options.name, None, None, None, None, "MAINTENANCE", None
     )
-    device = proxy.scheduler.devices.show(options.hostname)
+    device = proxy.scheduler.devices.show(options.name)
     current_job = device["current_job"]
     if current_job is not None:
         print("-> waiting for job %s" % current_job)
@@ -381,7 +381,7 @@ def handle_maintenance(proxy, options, _):
 
 
 def handle_show(proxy, options, config):
-    device = proxy.scheduler.devices.show(options.hostname)
+    device = proxy.scheduler.devices.show(options.name)
 
     if options.output_format == "json":
         print(json.dumps(device))
@@ -395,11 +395,13 @@ def handle_show(proxy, options, config):
             print("health      : %s" % device["health"])
         else:
             print("status      : %s" % device["status"])
-        print("user        : %s" % device["user"])
-        print("group       : %s" % device["group"])
+        if config["version"] < (2019, 9):
+            print("user        : %s" % device["user"])
+            print("group       : %s" % device["group"])
         print("health job  : %s" % device["health_job"])
         print("description : %s" % device["description"])
-        print("public      : %s" % device["public"])
+        if config["version"] < (2019, 9):
+            print("public      : %s" % device["public"])
         print("pipeline    : %s" % device["pipeline"])
         print("device-dict : %s" % device["has_device_dict"])
         print("worker      : %s" % device["worker"])
@@ -410,11 +412,11 @@ def handle_show(proxy, options, config):
 
 def handle_tags(proxy, options, _):
     if options.sub_sub_sub_command == "add":
-        proxy.scheduler.devices.tags.add(options.hostname, options.tag)
+        proxy.scheduler.devices.tags.add(options.name, options.tag)
     elif options.sub_sub_sub_command == "delete":
-        proxy.scheduler.devices.tags.delete(options.hostname, options.tag)
+        proxy.scheduler.devices.tags.delete(options.name, options.tag)
     else:
-        tags = proxy.scheduler.devices.tags.list(options.hostname)
+        tags = proxy.scheduler.devices.tags.list(options.name)
         if options.output_format == "json":
             print(json.dumps(tags))
         elif options.output_format == "yaml":
@@ -429,7 +431,7 @@ def handle_tags(proxy, options, _):
 def handle_update(proxy, options, config):
     if config["version"] >= (2018, 1):
         proxy.scheduler.devices.update(
-            options.hostname,
+            options.name,
             options.worker,
             options.user,
             options.group,
@@ -439,7 +441,7 @@ def handle_update(proxy, options, config):
         )
     else:
         proxy.scheduler.devices.update(
-            options.hostname,
+            options.name,
             options.worker,
             options.user,
             options.group,
