@@ -46,7 +46,7 @@ def configure_parser(parser, version):
 
         # "wait device"
         device_parser = obj_parser.add_parser("device")
-        device_parser.add_argument("hostname", type=str, help="hostname of the device")
+        device_parser.add_argument("name", type=str, help="name of the device")
         device_parser.add_argument(
             "--state",
             default=None,
@@ -85,7 +85,7 @@ def configure_parser(parser, version):
 
         # "wait worker"
         worker_parser = obj_parser.add_parser("worker")
-        worker_parser.add_argument("hostname", type=str, help="worker hostname")
+        worker_parser.add_argument("name", type=str, help="worker name")
         worker_parser.add_argument(
             "--state", default=None, choices=["ONLINE", "OFFLINE"], help="worker state"
         )
@@ -255,13 +255,13 @@ def handle_wait(proxy, options, config):
             continue
 
         if object_topic == "device":
-            if data.get("device") != options.hostname:
+            if data.get("device") != options.name:
                 continue
         elif object_topic == "testjob":
             if data.get("job") != options.job_id:
                 continue
         else:
-            if data.get("hostname") != options.hostname:
+            if data.get("hostname") != options.name:
                 continue
 
         # Filter by state
