@@ -93,7 +93,7 @@ def handle_list(proxy, options):
     if options.output_format == "json":
         print(json.dumps(tags))
     elif options.output_format == "yaml":
-        print(yaml.dump(tags).rstrip("\n"))
+        print(yaml.dump(tags, default_flow_style=None).rstrip("\n"))
     else:
         print("Tags:")
         for tag in tags:
@@ -109,7 +109,7 @@ def handle_show(proxy, options):
     if options.output_format == "json":
         print(json.dumps(tag))
     elif options.output_format == "yaml":
-        print(yaml.dump(tag).rstrip("\n"))
+        print(yaml.dump(tag, default_flow_style=None).rstrip("\n"))
     else:
         print("name       : %s" % tag["name"])
         print("description: %s" % tag["description"])
