@@ -23,13 +23,20 @@ import time
 import yaml
 
 
+def positive_integer(value):
+    int_value = int(value)
+    if int_value < 0:
+        raise argparse.ArgumentTypeError("%r should be a positive integer" % value)
+    return int_value
+
+
 def configure_parser(parser, version):
     sub = parser.add_subparsers(dest="sub_sub_command", help="Sub commands")
     sub.required = True
 
     # "add"
     workers_add = sub.add_parser("add", help="add a worker")
-    workers_add.add_argument("hostname", type=str, help="worker hostname")
+    workers_add.add_argument("name", type=str, help="worker name")
     workers_add.add_argument(
         "--description", type=str, default=None, help="worker description"
     )
@@ -47,10 +54,10 @@ def configure_parser(parser, version):
     )
     config_sub.required = True
     config_get = config_sub.add_parser("get", help="get the worker configuration")
-    config_get.add_argument("hostname", type=str, help="worker hostname")
+    config_get.add_argument("name", type=str, help="worker name")
 
     config_set = config_sub.add_parser("set", help="set the worker configuration")
-    config_set.add_argument("hostname", type=str, help="worker hostname")
+    config_set.add_argument("name", type=str, help="worker name")
     config_set.add_argument(
         "config", type=argparse.FileType("r"), help="configuration file"
     )
@@ -63,10 +70,10 @@ def configure_parser(parser, version):
         )
         env_sub.required = True
         env_get = env_sub.add_parser("get", help="get the worker environment")
-        env_get.add_argument("hostname", type=str, help="worker hostname")
+        env_get.add_argument("name", type=str, help="worker name")
 
         env_set = env_sub.add_parser("set", help="set the worker environment")
-        env_set.add_argument("hostname", type=str, help="worker hostname")
+        env_set.add_argument("name", type=str, help="worker name")
         env_set.add_argument(
             "env", type=argparse.FileType("r"), help="environment file"
         )
@@ -93,7 +100,7 @@ def configure_parser(parser, version):
 
     # "maintenance"
     workers_maintenance = sub.add_parser("maintenance", help="maintenance the worker")
-    workers_maintenance.add_argument("hostname", type=str, help="worker hostname")
+    workers_maintenance.add_argument("name", type=str, help="worker name")
     workers_maintenance.add_argument(
         "--force",
         default=False,
@@ -110,7 +117,7 @@ def configure_parser(parser, version):
 
     # "show"
     workers_show = sub.add_parser("show", help="show worker details")
-    workers_show.add_argument("hostname", help="worker hostname")
+    workers_show.add_argument("name", help="worker name")
     out_format = workers_show.add_mutually_exclusive_group()
     out_format.add_argument(
         "--json",
@@ -131,7 +138,7 @@ def configure_parser(parser, version):
 
     # "update"
     update_parser = sub.add_parser("update", help="update worker properties")
-    update_parser.add_argument("hostname", type=str, help="worker hostname")
+    update_parser.add_argument("name", type=str, help="worker name")
     update_parser.add_argument(
         "--description", type=str, default=None, help="worker description"
     )
@@ -159,6 +166,10 @@ def configure_parser(parser, version):
             dest="display",
             help="enable the worker",
         )
+    if version >= (2020, 1):
+        update_parser.add_argument(
+            "--job-limit", type=positive_integer, default=None, help="job limit"
+        )
 
 
 def help_string():
@@ -166,17 +177,17 @@ def help_string():
 
 
 def handle_add(proxy, options, _):
-    proxy.scheduler.workers.add(options.hostname, options.description, options.disabled)
+    proxy.scheduler.workers.add(options.name, options.description, options.disabled)
     return 0
 
 
 def handle_config(proxy, options, _):
     if options.sub_sub_sub_command == "get":
-        config = proxy.scheduler.workers.get_config(options.hostname)
+        config = proxy.scheduler.workers.get_config(options.name)
         print(str(config).rstrip("\n"))
     else:
         config = options.config.read()
-        ret = proxy.scheduler.workers.set_config(options.hostname, config)
+        ret = proxy.scheduler.workers.set_config(options.name, config)
         if not ret:
             print("Unable to store worker configuration")
             return 1
@@ -185,11 +196,11 @@ def handle_config(proxy, options, _):
 
 def handle_env(proxy, options, _):
     if options.sub_sub_sub_command == "get":
-        env = proxy.scheduler.workers.get_env(options.hostname)
+        env = proxy.scheduler.workers.get_env(options.name)
         print(str(env).rstrip("\n"))
     else:
         env = options.env.read()
-        ret = proxy.scheduler.workers.set_env(options.hostname, env)
+        ret = proxy.scheduler.workers.set_env(options.name, env)
         if not ret:
             print("Unable to store worker environment")
             return 1
@@ -210,10 +221,10 @@ def handle_list(proxy, options, _):
 
 
 def handle_maintenance(proxy, options, _):
-    proxy.scheduler.workers.update(options.hostname, None, "MAINTENANCE")
+    proxy.scheduler.workers.update(options.name, None, "MAINTENANCE")
 
     if options.force or options.wait:
-        worker_devices = proxy.scheduler.workers.show(options.hostname)["devices"]
+        worker_devices = proxy.scheduler.workers.show(options.name)["devices"]
         for device in proxy.scheduler.devices.list():
             if device["hostname"] not in worker_devices:
                 continue
@@ -234,7 +245,7 @@ def handle_maintenance(proxy, options, _):
 
 
 def handle_show(proxy, options, config):
-    worker = proxy.scheduler.workers.show(options.hostname)
+    worker = proxy.scheduler.workers.show(options.name)
     if options.output_format == "json":
         if "last_ping" in worker:
             worker["last_ping"] = worker["last_ping"].value
@@ -259,17 +270,24 @@ def handle_show(proxy, options, config):
             print("last ping   : %s" % worker["last_ping"])
         else:
             print("devices     : %d" % worker["devices"])
+
+        if config["version"] >= (2020, 1):
+            print("job limit   : %d" % worker["job_limit"])
     return 0
 
 
 def handle_update(proxy, options, config):
-    if config["version"] >= (2017, 12):
+    if config["version"] >= (2020, 1):
         proxy.scheduler.workers.update(
-            options.hostname, options.description, options.health
+            options.name, options.description, options.health, options.job_limit
+        )
+    elif config["version"] >= (2017, 12):
+        proxy.scheduler.workers.update(
+            options.name, options.description, options.health
         )
     else:
         proxy.scheduler.workers.update(
-            options.hostname, options.description, not options.display
+            options.name, options.description, not options.display
         )
     return 0
 
